@@ -1,11 +1,10 @@
 package File::Rename::Options;
-
 use strict;
-BEGIN { eval { require warnings; warnings->import } }
+use warnings;
 
-use Getopt::Long ();
+use Getopt::Long 2.24 ();
 
-our $VERSION = 1.99;
+our $VERSION = 2.00;
 our $IMPORTED;
 
 sub import {
@@ -19,8 +18,7 @@ sub import {
       no_ignore_case
     );
     push @config, @_;
-    eval{ Getopt::Long::Configure(@config); 1; }
-        or do { require Carp; Carp::carp($@) };
+    Getopt::Long::Configure(@config); 
 }
 
 sub GetOptions {
