@@ -33,7 +33,10 @@ sub create {
 sub listdir {
     my $d = shift;
     my $DIR;
-    unless ( opendir $DIR, $d ) { diag("Can't opendir $d: $!"); return }
+    unless ( opendir $DIR, $d ) {
+        diag("Can't opendir $d: $!");
+        return; 
+    }
     my @read = readdir $DIR;
     closedir $DIR or die $!;
     return ( grep { !/^\./ } @read );
@@ -70,7 +73,8 @@ sub test_rename_list {
 
 sub test_rename_function {
     my ( $function, $warning, $printed ) = @_;
-    our ( $found, $print, $warn ) = ();
+    our ( $found, $ warn ) = ();
+    our $print = '';
 
     {
         open my $stdout, '>', \$print or die;
@@ -101,7 +105,6 @@ sub test_rename_function {
             diag($printed);
         }
     }
-
     else {
         $found++ unless $warn or $print;
     }
